@@ -7,6 +7,7 @@ use warnings;
 use Memoize;
 
 memoize('_get_video_info');
+memoize('_ytdl_is_available');
 memoize('_extract_from_ytdl');
 memoize('_extract_from_invidious');
 
@@ -30,7 +31,7 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =cut
 
-our $VERSION = '3.7.9';
+our $VERSION = '3.8.0';
 
 =head1 SYNOPSIS
 
@@ -85,6 +86,10 @@ my %valid_options = (
     cache_dir   => {valid => qr/^./,     default => q{.}},
     cookie_file => {valid => qr/^./,     default => undef},
 
+    # Support for youtube-dl
+    ytdl     => {valid => [1, 0], default => 1},
+    ytdl_cmd => {valid => qr/\w/, default => "youtube-dl"},
+
     # Booleans
     env_proxy   => {valid => [1, 0], default => 1},
     escape_utf8 => {valid => [1, 0], default => 0},
@@ -242,7 +247,7 @@ sub set_lwp_useragent {
           // do { require LWP::UserAgent; 'LWP::UserAgent' }
     );
 
-    $self->{lwp} = $lwp->new(
+    my $agent = $lwp->new(
 
         cookie_jar    => {},                      # temporary cookies
         timeout       => $self->get_timeout,
@@ -288,7 +293,6 @@ sub set_lwp_useragent {
         HTTP::Message::decodable();
     };
 
-    my $agent = $self->{lwp};
     $agent->ssl_opts(Timeout => $self->get_timeout);
     $agent->default_header('Accept-Encoding' => $accepted_encodings);
     $agent->conn_cache($cache);
@@ -325,8 +329,9 @@ sub set_lwp_useragent {
         $agent->cookie_jar($cookies);
     }
 
-    push @{$self->{lwp}->requests_redirectable}, 'POST';
-    return $self->{lwp};
+    push @{$agent->requests_redirectable}, 'POST';
+    $self->{lwp} = $agent;
+    return $agent;
 }
 
 =head2 prepare_access_token()
@@ -572,7 +577,7 @@ sub select_good_invidious_instances {
 
     my %ignored = (
                    'yewtu.be'                 => 1,
-                   'invidiou.site'            => 0,
+                   'invidiou.site'            => 1,
                    'invidious.xyz'            => 1,
                    'vid.mint.lgbt'            => 1,
                    'invidious.ggc-project.de' => 1,
@@ -586,7 +591,11 @@ sub select_good_invidious_instances {
       grep { lc($_->[1]{type} // '') eq 'https' } @$instances;
 
     if ($self->get_debug) {
-        print STDERR ":: Found ", scalar(@candidates), " invidious instances.\n";
+
+        my @hosts = map { $_->[0] } @candidates;
+        my $count = scalar(@candidates);
+
+        print STDERR ":: Found $count invidious instances: @hosts\n";
     }
 
     return @candidates;
@@ -601,7 +610,6 @@ sub _extract_from_invidious {
         require List::Util;
         @instances = List::Util::shuffle(map { $_->[0] } @instances);
         push @instances, 'invidious.snopyta.org';
-        push @instances, 'invidious.13ad.de';
     }
     else {
         @instances = qw(
@@ -609,7 +617,6 @@ sub _extract_from_invidious {
           invidious.site
           invidious.fdn.fr
           invidious.snopyta.org
-          invidious.13ad.de
           );
     }
 
@@ -649,7 +656,8 @@ sub _extract_from_invidious {
 }
 
 sub _ytdl_is_available {
-    (state $x = system('youtube-dl', '--version')) == 0;
+    my ($self) = @_;
+    ($self->proxy_stdout($self->get_ytdl_cmd(), '--version') // '') =~ /\d/;
 }
 
 sub _extract_from_ytdl {
@@ -657,17 +665,16 @@ sub _extract_from_ytdl {
 
     $self->_ytdl_is_available() || return;
 
-    my @ytdl_cmd = ('youtube-dl', '--all-formats', '--dump-single-json');
+    my @ytdl_cmd = ($self->get_ytdl_cmd(), '--all-formats', '--dump-single-json');
 
     my $cookie_file = $self->get_cookie_file;
 
     if (defined($cookie_file) and -f $cookie_file) {
-        push @ytdl_cmd, '--cookies', $cookie_file;
+        push @ytdl_cmd, '--cookies', quotemeta($cookie_file);
     }
 
     my $json = $self->proxy_stdout(@ytdl_cmd, quotemeta("https://www.youtube.com/watch?v=" . $videoID));
-
-    my $ref = $self->parse_json_string($json);
+    my $ref  = $self->parse_json_string($json);
 
     my @formats;
     if (ref($ref) eq 'HASH' and exists($ref->{formats}) and ref($ref->{formats}) eq 'ARRAY') {
@@ -694,7 +701,7 @@ sub _fallback_extract_urls {
     my @formats;
 
     # Use youtube-dl
-    if ($self->_ytdl_is_available) {
+    if ($self->get_ytdl and $self->_ytdl_is_available) {
 
         if ($self->get_debug) {
             say STDERR ":: Using youtube-dl to extract the streaming URLs...";
@@ -1085,6 +1092,10 @@ sub post_as_json {
 sub from_page_token {
     my ($self, $url, $token) = @_;
 
+    if (ref($token) eq 'CODE') {
+        return $token->();
+    }
+
     my $pt_url = (
                   defined($token)
                   ? (
@@ -1117,6 +1128,8 @@ sub from_page_token {
             local $ENV{HTTP_PROXY}  = $self->{lwp}->proxy('http');
             local $ENV{HTTPS_PROXY} = $self->{lwp}->proxy('https');
 
+            local $" = " ";
+
                 $name eq 'exec'   ? exec(@args)
               : $name eq 'system' ? system(@args)
               : $name eq 'stdout' ? qx(@args)
